Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/Duet3D/RepRapFirmware.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorDavid Crocker <dcrocker@eschertech.com>2022-08-07 19:48:42 +0300
committerDavid Crocker <dcrocker@eschertech.com>2022-08-07 19:48:42 +0300
commit581c47b7e1a137332ace62166978f13126db7b05 (patch)
tree4d997ac5c2e03f11d32c07644bfc8e07f64354f6
parent62f23e2281b9a345cebf811ee2306fab49bd63ce (diff)
Increase maximum G0 feed rate in CNC mode from 300 to 1000mm/sec
-rw-r--r--src/Config/Configuration.h2
-rw-r--r--src/GCodes/GCodes.cpp2
2 files changed, 2 insertions, 2 deletions
diff --git a/src/GCodes/GCodes.cpp b/src/GCodes/GCodes.cpp
index 53acec04..e8ceed43 100644
--- a/src/GCodes/GCodes.cpp
+++ b/src/GCodes/GCodes.cpp
@@ -1494,7 +1494,7 @@ const char * GCodes::LoadExtrusionAndFeedrateFromGCode(GCodeBuffer& gb, bool isP
else
{
moveState.applyM220M221 = false;
- moveState.feedRate = ConvertSpeedFromMmPerMin(DefaultG0FeedRate); // use maximum feed rate, the M203 parameters will limit it
+ moveState.feedRate = ConvertSpeedFromMmPerMin(MaximumG0FeedRate); // use maximum feed rate, the M203 parameters will limit it
moveState.usingStandardFeedrate = false;
}
diff --git a/src/Config/Configuration.h b/src/Config/Configuration.h
index aa02d818..1fd6f7b1 100644
--- a/src/Config/Configuration.h
+++ b/src/Config/Configuration.h
@@ -218,7 +218,7 @@ constexpr unsigned int MaxFilaments = 8;
// Move system
constexpr float DefaultFeedRate = 3000.0; // The initial requested feed rate after resetting the printer, in mm/min
-constexpr float DefaultG0FeedRate = 18000.0; // The initial feed rate for G0 commands after resetting the printer, in mm/min
+constexpr float MaximumG0FeedRate = 60000.0; // The maximum feed rate for G0 commands in mm/min, if the M203 settings permit
constexpr float MinRetractSpeed = 60.0; // The minimum firmware retraction/un-retraction speed in mm/min
constexpr float DefaultRetractSpeed = 1000.0; // The default firmware retraction and un-retraction speed, in mm/min
constexpr float DefaultRetractLength = 2.0;